@@ -433,36 +433,6 @@ def signal_correction_algebric(signal_data,S_matrix, R_matrix, T_matrix,  mesh_p
     # Time array at the SSB position
     t_prime = np.arange(t1,t2,1/f_sampling) # must to be t2 (currently in test phase)
 
-
-    # definition of the matrix S linearized
-    #S_matrix = S_linearized(esh_x,mesh_y,mesh_z)
-
-    #compute the R_matrix
-    # THIS MATRIX CAN BE REALLLY BIG 3*len(SIGNAL) close to the Billion.
-    #R_matrix= R_matrix_compute(t1,t2,f_sampling)
-
-    #compute T_matrix
-    #T_matrix = T_matrix_compute()
-
-    #we call the BLAS Matrix multiplication for CUDA
-
-    # C= T_matrix
-    # beta= 1
-    # A= S_matrix
-    # B= R_matrix
-    # alpha = 1/c
-    # m= nb_line ? (360*180)/pres
-    # n= nb_column ? (t2-t1)*f_sampling
-    # k= matrix rank ???
-
-    m= (360*180)/mesh_precision
-    n= 3
-    k= (t2-t1)*f_sampling
-    #C at the end contain every delta_t for each point in 1 column for a specific time.
-    #pyculib.blas.Blas.gemm(transa, transb, m, n, k, alpha, A, B, beta, C)
-    # utiliser cupy.matmul for matrix multiplication ?
-    #pyculib.blas.Blas.gemm(np.transpose(S_matrix), np.transpose(R_matrix), m, n, k, (1/c).value, S_matrix, R_matrix, 1, T_matrix)
-
     #cupy Version (CUDA kernel)
     #compute scalar product
     mult_res=(1/c.value)*cupy.matmul(cupy.array(S_matrix),cupy.array(R_matrix))
@@ -648,7 +618,7 @@ def R_matrix_compute(t1,t2,f_sampling):
     return matrix_result
 
 
-
+# compute the R matrix
 def R_matrix_parrallel(t1,t2,f_sampling):
 
     #local function for parallelisation
@@ -673,9 +643,60 @@ def R_matrix_parrallel(t1,t2,f_sampling):
     para_pool=Parallel(n_jobs=number_of_cpu)
     result_matrix=para_pool(delayed_funcs)
 
-    return result_matrix
+    return np.transpose(np.array(result_matrix))
+
 
 
 #------------------------------------------------------------------------------#
 #------------------------------ ROEMER EFFECT ---------------------------------#
 #------------------------------------------------------------------------------#
+
+
+
+
+# Function to build the signal from new time table
+# Sequential version
+# we work signal per signal (Time priority)
+def build_ssb_signal(SSB_time_table,data,pres=1e-4):
+    """
+    This function build the SSB signal from the new time table computed by delete_doppler()
+    .. warning::
+
+        CUDA version will be soon as possible proposed
+
+    :param SSB_time_table: numpy array of the new date .
+    :param t2: *TimeSerie* GW data.
+    :output : *Timeseries* Signal in the SSB frame.
+
+    """
+    #We search for each time-value the closest value in the raw signal (after treatment ?)
+    new_signal= np.zeros(len(first_signal))
+
+    # we loop in every value of T_ssb
+    for k in range(len(first_signal)):
+
+        #compute perfect position
+        x=(first_signal[k]-h_data.t0.value)/h_data.dt.value
+
+        high= np.ceil(x)
+        low = int(high-1)
+
+        #
+        if (abs(first_signal[k]-low) < abs(first_signal[k] - high)):
+            new_signal[k]=h_data[low]
+
+        #
+        if (abs(first_signal[k]-low) == abs(first_signal[k] - high)):
+            new_signal[k]=h_data[low]
+
+        #
+        else:
+            new_signal[k]=h_data[low]
+
+
+    #build result as TimeSeries
+    T_new_sig= TimeSeries(new_signal)
+    T_new_sig.dt=data.dt.value
+    T_new_sig.d0=data.d0.value
+
+    return T_new_sig
