@@ -319,7 +319,7 @@ def inject_signal(array,t0,f_obs,f_sampling,A,phase):
 
     thread_global_id    = cuda.grid(1)
     #read the frequency at the specific time
-    f = f_obs[thread_global_id]
+    f = f_obs[thread_global_id][0]
 
     #compute GPS time
     time = t0+(thread_global_id*f_sampling)
